﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using NHibernate;
using Dnad09.Blog.Dominio.Entidades;
using NHibernate.Criterion;

namespace Dnad09.Blog.Repositorio
{
    public class RepositorioBase<TEntidade> where TEntidade : EntidadeComId
    {

        public RepositorioBase(ISession session)
        {
            if (session == null)
                throw new ArgumentException("A session deve existir.", "session");
            _session = session;
        }
        private readonly ISession _session;
        protected ISession Session
        {
            get { return _session; }
        }

        public void Salvar(TEntidade entidade)
        {
            using (var trans = Session.BeginTransaction())
            {
                this.Session.SaveOrUpdate(entidade);
                trans.Commit();
            }
        }

        public void Excluir(int id)
        {
            var entidade = this.ObterPorId(id);
            if (entidade == null)
                return;
            using (var trans = Session.BeginTransaction())
            {
                this.Session.Delete(entidade);
                trans.Commit();
            }
        }

        public TEntidade ObterPorId(int id)
        {
            var entidade = this.Session.Get<TEntidade>(id);
            return entidade;
        }

        public IList<TEntidade> ObterTodos()
        {
            var entidades = this
                .Session
                .CreateCriteria(typeof(TEntidade))
                .AddOrder(Order.Asc("Id"))
                .List<TEntidade>();
            return entidades;
        }    

    }
}
