﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Mvc.Ajax;
using Dnad09.Blog.Dominio.Entidades;
using Dnad09.Blog.Repositorio;
using Dnad09.Blog.Repositorio.Config;
using Dnad09.Blog.Consultas;
using Dnad09.Blog.Consultas.DTOs;

namespace Dnad09.Blog.WebApp.Controllers
{
    public class PostagemController : Controller
    {

        private readonly RepositorioPostagem _repositorio;
        private readonly ConsultaPostagem _consulta;
        public PostagemController()
        {
            var fabricaSessao = Autoconfiguracao.Configurar();
            var sessao = fabricaSessao.OpenSession();
            _repositorio = new RepositorioPostagem(sessao);
            _consulta = new ConsultaPostagem(sessao);
        }

        //
        // GET: /Postagem/

        public ActionResult Index()
        {
            var postagens = _repositorio.ObterTodos();
            return View(postagens);
        }

        public ActionResult PostagensComTotalDeComentarios(string autor, int pagina)
        {
            var postagens = _consulta.ObterPostagensComTotalDeComentarios(autor, pagina);
            return View(postagens);
        }

        //
        // GET: /Postagem/Details/5

        public ActionResult Details(int id)
        {
            var postagem = _repositorio.ObterPorId(id);
            return View(postagem);
        }

        //
        // GET: /Postagem/Create

        public ActionResult Create()
        {
            return View(new Postagem());
        } 

        //
        // POST: /Postagem/Create

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult Create(Postagem postagem)
        {
            try
            {
                _repositorio.Salvar(postagem);
                return RedirectToAction("Index");
            }
            catch
            {
                return View(postagem);
            }
        }

        //
        // GET: /Postagem/Edit/5

        public ActionResult Edit(int id)
        {
            var postagem = _repositorio.ObterPorId(id);
            return View(postagem);
        }

        public ActionResult Delete(int id)
        {
            _repositorio.Excluir(id);
            return RedirectToAction("Index");
        }

        //
        // POST: /Postagem/Edit/5

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult Edit(int id, Postagem postagem)
        {
            try
            {
                _repositorio.Salvar(postagem);
                return RedirectToAction("Index");
            }
            catch
            {
                return View(postagem);
            }
        }
    }
}
